import { Location } from './location';
import { Retrieval } from './retrieval';
import { PlyOptions } from './options';
import { ResultPaths } from './result';
import { TestSuite, TestCase, Before, After } from './decorators';
/**
 * Runtime information for a test suite.
 */
export declare class Runtime {
    readonly options: PlyOptions;
    readonly retrieval: Retrieval;
    results: ResultPaths;
    testsLocation: Location;
    decoratedSuite?: DecoratedSuite;
    /**
     * Verified response header names.
     */
    responseHeaders: string[] | undefined;
    constructor(options: PlyOptions, retrieval: Retrieval, results: ResultPaths);
    get suitePath(): string;
    appendResult(line: string, level?: number, withExpected?: boolean, comment?: string): void;
}
export declare type CallingCaseInfo = {
    results: ResultPaths;
    suiteName: string;
    caseName: string;
};
/**
 * Applicable for Cases
 */
export declare class DecoratedSuite {
    readonly instance: any;
    readonly testSuite: TestSuite;
    readonly testCases: TestCase[];
    readonly befores: Before[];
    readonly afters: After[];
    /**
     * @param instance runtime instance of a suite
     */
    constructor(instance: any);
    private runIfMatch;
    private isMatch;
    runBefores(test: string, values: object): Promise<void>;
    runAfters(test: string, values: object): Promise<void>;
}
