"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replace = void 0;
const names_1 = require("./names");
const util = require("./util");
/**
 * duplicated in vscode-ply/media/values.ts
 */
function get(input, context) {
    if (input.startsWith('${~'))
        return input; // ignore regex
    // escape all \
    let path = input.replace(/\\/g, '\\\\');
    // trim ${ and }
    path = path.substring(2, path.length - 1);
    // directly contains expression (flat obj or user-entered values in vscode)
    const type = typeof context[path];
    if (type === 'string' || type === 'number' || type === 'boolean') {
        return context[path];
    }
    let res = context;
    for (let seg of path.split('.')) {
        const idx = seg.search(/\[.+?]$/);
        let indexer;
        if (idx > 0) {
            indexer = seg.substring(idx + 1, seg.length - 1);
            seg = seg.substring(0, idx);
        }
        if (!res[seg])
            return input;
        res = res[seg];
        if (indexer) {
            if ((indexer.startsWith("'") || indexer.startsWith('"')) &&
                (indexer.endsWith("'") || indexer.endsWith('"'))) {
                res = res[indexer.substring(1, indexer.length - 1)]; // object property
            }
            else {
                res = res[parseInt(indexer)]; // array index
            }
        }
    }
    return '' + res;
}
/**
 * Replaces template expressions with values from context (per line).
 * Supports a limited subset of template literal expressions
 * Ignores regular expressions starting with ${~.
 * Resulting newlines are always \n
 */
function replace(template, context, logger) {
    const lines = [];
    for (const line of util.lines(template)) {
        try {
            let l = line.replace(/\${@\[/g, '${' + names_1.RESULTS + '[');
            l = l.replace(/\${@/g, '${' + names_1.RESULTS + '.');
            lines.push(l.replace(/\$\{.+?}/g, expr => get(expr, context)));
        }
        catch (err) {
            if (err.message === `${names_1.RESULTS} is not defined`) {
                err.message = 'No previous results found';
            }
            logger.error(`Error in expression:\n${line}\n** ${err.message} **`);
            logger.debug(err);
            lines.push(line);
        }
    }
    return lines.join('\n');
}
exports.replace = replace;
//# sourceMappingURL=subst.js.map