"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = exports.dump = void 0;
const jsYaml = require("js-yaml");
const util = require("./util");
function dump(obj, indent) {
    return jsYaml.dump(obj, { noCompatMode: true, skipInvalid: true, indent, lineWidth: -1 });
}
exports.dump = dump;
function load(file, contents, assignLines = false) {
    const lines = {};
    const obj = jsYaml.load(contents, {
        filename: file,
        listener: function (op, state) {
            if (assignLines && op === 'open' && state.kind === 'scalar') {
                lines[state.result] = state.line;
            }
        }
    });
    if (obj && assignLines) {
        const contentLines = util.lines(contents);
        let lastObjProp;
        Object.keys(obj).forEach(key => {
            const line = lines[key];
            if (typeof line !== 'undefined' && typeof obj[key] === 'object') {
                if (!obj[key]) {
                    obj[key] = {};
                }
                const objProp = obj[key];
                objProp.__start = line;
                if (lastObjProp && typeof lastObjProp.__start !== 'undefined' && typeof objProp.__start !== 'undefined') {
                    lastObjProp.__end = getEndLine(contentLines, lastObjProp.__start, objProp.__start - 1);
                }
                lastObjProp = objProp;
            }
        });
        if (lastObjProp && typeof lastObjProp.__start !== 'undefined') {
            lastObjProp.__end = getEndLine(contentLines, lastObjProp.__start);
        }
    }
    return obj;
}
exports.load = load;
function getEndLine(contentLines, start, end = undefined) {
    const reversedLines = getLines(contentLines, start, end).reverse();
    let endLine = typeof end === 'undefined' ? (start + reversedLines.length - 1) : end;
    for (let i = 0; i < reversedLines.length && endLine > start; i++) {
        const line = reversedLines[i].trim();
        if (!line || line.startsWith('#')) {
            endLine--;
        }
        else {
            break;
        }
    }
    return endLine;
}
/**
 * Returns content lines where index is between start and end - 1.
 * If end is not supplied, read to end of contentLines array.
 */
function getLines(contentLines, start, end) {
    return contentLines.reduce((lines, line, i) => {
        if (i >= start && (!end || i <= end)) {
            lines.push(line);
        }
        return lines;
    }, new Array());
}
//# sourceMappingURL=yaml.js.map